==> apache-camel-4.0.1-src.zip: apache-camel-4.0.1/components/camel-as2/camel-as2-component/src/main/java/org/apache/camel/component/as2/internal/AS2PropertiesHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.as2.internal;

import org.apache.camel.CamelContext;
import org.apache.camel.component.as2.AS2Configuration;
import org.apache.camel.support.component.ApiMethodPropertiesHelper;

/**
 * Singleton {@link ApiMethodPropertiesHelper} for AS2 component.
 */
public final class AS2PropertiesHelper extends ApiMethodPropertiesHelper<AS2Configuration> {

    private static AS2PropertiesHelper helper;

    private AS2PropertiesHelper(CamelContext context) {
        super(context, AS2Configuration.class, AS2Constants.PROPERTY_PREFIX);
    }

    public static synchronized AS2PropertiesHelper getHelper(CamelContext context) {
        if (helper == null) {
            helper = new AS2PropertiesHelper(context);
        }
        return helper;
    }
}

==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/components/camel-as2/camel-as2-component/src/main/java/org/apache/camel/component/as2/internal/AS2PropertiesHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.as2.internal;

import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

import org.apache.camel.CamelContext;
import org.apache.camel.component.as2.AS2Configuration;
import org.apache.camel.support.component.ApiMethodPropertiesHelper;

/**
 * Singleton {@link ApiMethodPropertiesHelper} for AS2 component.
 */
public final class AS2PropertiesHelper extends ApiMethodPropertiesHelper<AS2Configuration> {

    private static final Lock LOCK = new ReentrantLock();
    private static AS2PropertiesHelper helper;

    private AS2PropertiesHelper(CamelContext context) {
        super(context, AS2Configuration.class, AS2Constants.PROPERTY_PREFIX);
    }

    public static AS2PropertiesHelper getHelper(CamelContext context) {
        LOCK.lock();
        try {
            if (helper == null) {
                helper = new AS2PropertiesHelper(context);
            }
            return helper;
        } finally {
            LOCK.unlock();
        }
    }
}
